##  Overview
Use diagram templates to define reusable rules for how fact sheet data is visualized in diagrams. This page explains how to:
  * Create a new diagram template from a base fact sheet type or an out-of-the-box preset.
  * Add and remove allowed elements such as dependency relations and drill-downs.
  * Review automatic layout and save behavior.
  * Set and save a default view and relevant labels for a template.
